Welcome to Hedju's documentation!
=================================

.. note:: This is pre-alpha code. Use at your own discretion.

Hedju is a collection of classes that are designed to replace original DRF
pagination classes and provide pagination using Link header.
If client somehow does not support Link header, it can still ask for enveloped
data.

Developed by SUNSCRAPERS_ with passion & patience.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _SUNSCRAPERS: https://sunscrapers.com/
